/****************************************************************************
** QgsMapLayer meta object code from reading C++ file 'qgsmaplayer.h'
**
** Created: Fri Nov 4 14:08:55 2005
**      by: The Qt MOC ($Id: qt/moc_yacc.cpp   3.3.4   edited Jan 21 18:14 $)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#undef QT_NO_COMPAT
#include "qgsmaplayer.h"
#include <qmetaobject.h>
#include <qapplication.h>

#include <private/qucomextra_p.h>
#if !defined(Q_MOC_OUTPUT_REVISION) || (Q_MOC_OUTPUT_REVISION != 26)
#error "This file was generated using the moc from 3.3.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

const char *QgsMapLayer::className() const
{
    return "QgsMapLayer";
}

QMetaObject *QgsMapLayer::metaObj = 0;
static QMetaObjectCleanUp cleanUp_QgsMapLayer( "QgsMapLayer", &QgsMapLayer::staticMetaObject );

#ifndef QT_NO_TRANSLATION
QString QgsMapLayer::tr( const char *s, const char *c )
{
    if ( qApp )
	return qApp->translate( "QgsMapLayer", s, c, QApplication::DefaultCodec );
    else
	return QString::fromLatin1( s );
}
#ifndef QT_NO_TRANSLATION_UTF8
QString QgsMapLayer::trUtf8( const char *s, const char *c )
{
    if ( qApp )
	return qApp->translate( "QgsMapLayer", s, c, QApplication::UnicodeUTF8 );
    else
	return QString::fromUtf8( s );
}
#endif // QT_NO_TRANSLATION_UTF8

#endif // QT_NO_TRANSLATION

QMetaObject* QgsMapLayer::staticMetaObject()
{
    if ( metaObj )
	return metaObj;
    QMetaObject* parentObject = QObject::staticMetaObject();
    static const QUMethod slot_0 = {"invalidTransformInput", 0, 0 };
    static const QUParameter param_slot_1[] = {
	{ "e", &static_QUType_ptr, "QKeyEvent", QUParameter::In }
    };
    static const QUMethod slot_1 = {"keyPressed", 1, param_slot_1 };
    static const QUParameter param_slot_2[] = {
	{ "vis", &static_QUType_bool, 0, QUParameter::In }
    };
    static const QUMethod slot_2 = {"setVisible", 1, param_slot_2 };
    static const QUMethod slot_3 = {"updateItemPixmap", 0, 0 };
    static const QUMethod slot_4 = {"updateOverviewPopupItem", 0, 0 };
    static const QUParameter param_slot_5[] = {
	{ 0, &static_QUType_bool, 0, QUParameter::In }
    };
    static const QUMethod slot_5 = {"inOverview", 1, param_slot_5 };
    static const QUParameter param_slot_6[] = {
	{ "theMinScale", &static_QUType_ptr, "float", QUParameter::In }
    };
    static const QUMethod slot_6 = {"setMinScale", 1, param_slot_6 };
    static const QUMethod slot_7 = {"minScale", 0, 0 };
    static const QUParameter param_slot_8[] = {
	{ "theMaxScale", &static_QUType_ptr, "float", QUParameter::In }
    };
    static const QUMethod slot_8 = {"setMaxScale", 1, param_slot_8 };
    static const QUMethod slot_9 = {"maxScale", 0, 0 };
    static const QUParameter param_slot_10[] = {
	{ "theVisibilityFlag", &static_QUType_bool, 0, QUParameter::In }
    };
    static const QUMethod slot_10 = {"setScaleBasedVisibility", 1, param_slot_10 };
    static const QUParameter param_slot_11[] = {
	{ 0, &static_QUType_bool, 0, QUParameter::Out }
    };
    static const QUMethod slot_11 = {"scaleBasedVisibility", 1, param_slot_11 };
    static const QUParameter param_slot_12[] = {
	{ 0, &static_QUType_QString, 0, QUParameter::Out }
    };
    static const QUMethod slot_12 = {"getProjectionWKT", 1, param_slot_12 };
    static const QMetaData slot_tbl[] = {
	{ "invalidTransformInput()", &slot_0, QMetaData::Public },
	{ "keyPressed(QKeyEvent*)", &slot_1, QMetaData::Public },
	{ "setVisible(bool)", &slot_2, QMetaData::Public },
	{ "updateItemPixmap()", &slot_3, QMetaData::Public },
	{ "updateOverviewPopupItem()", &slot_4, QMetaData::Public },
	{ "inOverview(bool)", &slot_5, QMetaData::Public },
	{ "setMinScale(float)", &slot_6, QMetaData::Public },
	{ "minScale()", &slot_7, QMetaData::Public },
	{ "setMaxScale(float)", &slot_8, QMetaData::Public },
	{ "maxScale()", &slot_9, QMetaData::Public },
	{ "setScaleBasedVisibility(bool)", &slot_10, QMetaData::Public },
	{ "scaleBasedVisibility()", &slot_11, QMetaData::Public },
	{ "getProjectionWKT()", &slot_12, QMetaData::Public }
    };
    static const QUMethod signal_0 = {"visibilityChanged", 0, 0 };
    static const QUParameter param_signal_1[] = {
	{ "theProgress", &static_QUType_int, 0, QUParameter::In },
	{ "theTotalSteps", &static_QUType_int, 0, QUParameter::In }
    };
    static const QUMethod signal_1 = {"setProgress", 2, param_signal_1 };
    static const QUParameter param_signal_2[] = {
	{ "theStatusQString", &static_QUType_QString, 0, QUParameter::In }
    };
    static const QUMethod signal_2 = {"setStatus", 1, param_signal_2 };
    static const QUMethod signal_3 = {"repaintRequested", 0, 0 };
    static const QUParameter param_signal_4[] = {
	{ "maplayer", &static_QUType_ptr, "QgsMapLayer", QUParameter::In },
	{ 0, &static_QUType_bool, 0, QUParameter::In }
    };
    static const QUMethod signal_4 = {"showInOverview", 2, param_signal_4 };
    static const QUMethod signal_5 = {"recalculateExtents", 0, 0 };
    static const QMetaData signal_tbl[] = {
	{ "visibilityChanged()", &signal_0, QMetaData::Public },
	{ "setProgress(int,int)", &signal_1, QMetaData::Public },
	{ "setStatus(QString)", &signal_2, QMetaData::Public },
	{ "repaintRequested()", &signal_3, QMetaData::Public },
	{ "showInOverview(QgsMapLayer*,bool)", &signal_4, QMetaData::Public },
	{ "recalculateExtents()", &signal_5, QMetaData::Public }
    };
    metaObj = QMetaObject::new_metaobject(
	"QgsMapLayer", parentObject,
	slot_tbl, 13,
	signal_tbl, 6,
#ifndef QT_NO_PROPERTIES
	0, 0,
	0, 0,
#endif // QT_NO_PROPERTIES
	0, 0 );
    cleanUp_QgsMapLayer.setMetaObject( metaObj );
    return metaObj;
}

void* QgsMapLayer::qt_cast( const char* clname )
{
    if ( !qstrcmp( clname, "QgsMapLayer" ) )
	return this;
    return QObject::qt_cast( clname );
}

// SIGNAL visibilityChanged
void QgsMapLayer::visibilityChanged()
{
    activate_signal( staticMetaObject()->signalOffset() + 0 );
}

#include <qobjectdefs.h>
#include <qsignalslotimp.h>

// SIGNAL setProgress
void QgsMapLayer::setProgress( int t0, int t1 )
{
    if ( signalsBlocked() )
	return;
    QConnectionList *clist = receivers( staticMetaObject()->signalOffset() + 1 );
    if ( !clist )
	return;
    QUObject o[3];
    static_QUType_int.set(o+1,t0);
    static_QUType_int.set(o+2,t1);
    activate_signal( clist, o );
}

// SIGNAL setStatus
void QgsMapLayer::setStatus( QString t0 )
{
    activate_signal( staticMetaObject()->signalOffset() + 2, t0 );
}

// SIGNAL repaintRequested
void QgsMapLayer::repaintRequested()
{
    activate_signal( staticMetaObject()->signalOffset() + 3 );
}

// SIGNAL showInOverview
void QgsMapLayer::showInOverview( QgsMapLayer* t0, bool t1 )
{
    if ( signalsBlocked() )
	return;
    QConnectionList *clist = receivers( staticMetaObject()->signalOffset() + 4 );
    if ( !clist )
	return;
    QUObject o[3];
    static_QUType_ptr.set(o+1,t0);
    static_QUType_bool.set(o+2,t1);
    activate_signal( clist, o );
}

// SIGNAL recalculateExtents
void QgsMapLayer::recalculateExtents()
{
    activate_signal( staticMetaObject()->signalOffset() + 5 );
}

bool QgsMapLayer::qt_invoke( int _id, QUObject* _o )
{
    switch ( _id - staticMetaObject()->slotOffset() ) {
    case 0: invalidTransformInput(); break;
    case 1: keyPressed((QKeyEvent*)static_QUType_ptr.get(_o+1)); break;
    case 2: setVisible((bool)static_QUType_bool.get(_o+1)); break;
    case 3: updateItemPixmap(); break;
    case 4: updateOverviewPopupItem(); break;
    case 5: inOverview((bool)static_QUType_bool.get(_o+1)); break;
    case 6: setMinScale((float)(*((float*)static_QUType_ptr.get(_o+1)))); break;
    case 7: minScale(); break;
    case 8: setMaxScale((float)(*((float*)static_QUType_ptr.get(_o+1)))); break;
    case 9: maxScale(); break;
    case 10: setScaleBasedVisibility((bool)static_QUType_bool.get(_o+1)); break;
    case 11: static_QUType_bool.set(_o,scaleBasedVisibility()); break;
    case 12: static_QUType_QString.set(_o,getProjectionWKT()); break;
    default:
	return QObject::qt_invoke( _id, _o );
    }
    return TRUE;
}

bool QgsMapLayer::qt_emit( int _id, QUObject* _o )
{
    switch ( _id - staticMetaObject()->signalOffset() ) {
    case 0: visibilityChanged(); break;
    case 1: setProgress((int)static_QUType_int.get(_o+1),(int)static_QUType_int.get(_o+2)); break;
    case 2: setStatus((QString)static_QUType_QString.get(_o+1)); break;
    case 3: repaintRequested(); break;
    case 4: showInOverview((QgsMapLayer*)static_QUType_ptr.get(_o+1),(bool)static_QUType_bool.get(_o+2)); break;
    case 5: recalculateExtents(); break;
    default:
	return QObject::qt_emit(_id,_o);
    }
    return TRUE;
}
#ifndef QT_NO_PROPERTIES

bool QgsMapLayer::qt_property( int id, int f, QVariant* v)
{
    return QObject::qt_property( id, f, v);
}

bool QgsMapLayer::qt_static_property( QObject* , int , int , QVariant* ){ return FALSE; }
#endif // QT_NO_PROPERTIES
